@@ -3,7 +3,7 @@ package App::TableDataUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-29'; # DATE
 our $DIST = 'App-TableDataUtils'; # DIST
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.050'; # VERSION
 
 use 5.010001;
 use strict;
@@ -140,6 +140,25 @@ sub gen_rand_aohos {
     [200, "OK", $aohos];
 }
 
+$SPEC{td2csv} = {
+    v => 1.1,
+    summary => 'Convert table data in STDIN to CSV',
+    description => <<'_',
+
+Actually alias for `td as-csv`.
+
+_
+    args => {
+    },
+};
+sub td2csv {
+    require App::td;
+
+    my %args = @_;
+
+    App::td::td(action => 'as-csv');
+}
+
 1;
 # ABSTRACT: Routines related to table data
 
@@ -155,7 +174,7 @@ App::TableDataUtils - Routines related to table data
 
 =head1 VERSION
 
-This document describes version 0.04 of App::TableDataUtils (from Perl distribution App-TableDataUtils), released on 2020-05-29.
+This document describes version 0.050 of App::TableDataUtils (from Perl distribution App-TableDataUtils), released on 2020-05-29.
 
 =head1 DESCRIPTION
 
@@ -165,6 +184,8 @@ This distribution includes a few utility scripts related to table data.
 
 =item * L<gen-rand-table>
 
+=item * L<td2csv>
+
 =back
 
 =head1 FUNCTIONS
@@ -312,6 +333,33 @@ that contains extra information.
 
 Return value:  (any)
 
+
+
+=head2 td2csv
+
+Usage:
+
+ td2csv() -> [status, msg, payload, meta]
+
+Convert table data in STDIN to CSV.
+
+Actually alias for C<td as-csv>.
+
+This function is not exported.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-TableDataUtils>.
